/***************************************************************************
 $RCSfile: openhbci.h.in,v $
 -------------------
 cvs         : $Id: openhbci.h.in,v 1.22 2003/01/29 12:20:53 cstim Exp $
 begin       : Fri Dec 07 2001
 copyright   : (C) 2001 by Martin Preuss
 email       : martin@aquamaniac.de
***************************************************************************/


/***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

/** @file openhbci.h
 * @short Includes all OpenHBCI headers.
 */

#ifndef OPENHBCI_H
#define OPENHBCI_H

#define OPENHBCI_VERSION_MAJOR 0
#define OPENHBCI_VERSION_MINOR 9
#define OPENHBCI_VERSION_PATCHLEVEL 7
#define OPENHBCI_VERSION_STRING "0.9.7"





// STL
#ifdef __cplusplus
#include <string>
#include <list>
#endif // __cplusplus

// Helper classes for applications
#include <openhbci/dllimport.h>
#ifdef __cplusplus
#include <openhbci/tree.h>
#include <openhbci/conf.h>
#include <openhbci/simpleconfig.h>
#include <openhbci/cmdlineoptions.h>
#include <openhbci/filestream.h>
#include <openhbci/parser.h>
#include <openhbci/stream.h>
#include <openhbci/directory.h>
#endif // __cplusplus

// Core HBCI classes that aren't included through api.h
#ifdef __cplusplus
# include <openhbci/hbcistring.h>
#endif // __cplusplus
#include <openhbci/mediumrdhbase.h>
#include <openhbci/mediumddv.h>
#ifdef __cplusplus
#ifdef SUPPORTING_RSACARD
# include <openhbci/mediumrsacard.h>
#endif
#endif // __cplusplus

// HBCI classes on wrapper layer
// Most stuff is included by api.h anyway
#include <openhbci/api.h> 
#include <openhbci/outbox.h>
#include <openhbci/outboxjob.h>
#include <openhbci/outboxjobs.h>
#include <openhbci/outboxaccjobs.h>
#include <openhbci/outboxstojobs.h>
#include <openhbci/outboxjobkeys.h>


/* //////////////////////////////////////////////////////////////////
// see http://www.stack.nl/~dimitri/doxygen/faq.html on how to get
// information on the index page for doxygen. */

/** @mainpage OpenHBCI Documentation Main Page
 *
@section quickstart Quickstart
 
To get down to coding really quickly, create an object of class
@ref HBCI::API and follow the instructions provided there (or 
in C: @ref HBCI_API).
 
@section hbci What is HBCI

%HBCI - <b>H</b>ome<b>B</b>anking <b>C</b>omputer <b>I</b>nterface

%HBCI is a bank-independent homebanking standard, developed by the
german <a href="http://www.hbci-zka.de/">ZKA ("Zentraler
Kredit-Ausschuss"</a>, German Central Banking Committe).
It is a publicly available protocol specification that defines the
communication between homebanking applications and the credit
institutes' servers.

@section openhbci What is OpenHBCI

OpenHBCI is a client-side implementation of the %HBCI
specification. That means, you can use OpenHCBI in a homebanking
application to connect to and talk to any %HBCI-capable bank server.

OpenHBCI provides an object oriented library to give you easy access
to credit institutes that support the %HBCI-standard. The library is
written in C++;  C wrappers are provided as well.  OpenHBCI hides
all the protocol-stuff, the encryption, the communication... so that
developers of homebanking-software can concentrate on their
application without having to read about <i>700</i> pages of
specification.

@section not What is OpenHBCI not

<ul>

<li>OpenHBCI <i>is not a homebanking application</i>, instead it is
a <i>library</i> offering homebanking functionality. 
If you need a homebanking application, go to 
<a href="http://aqmoney.sourceforge.net">AqMoney</a> 
which offers basic command-line homebanking, or check out the list 
of applications <a
href="http://openhbci.sourceforge.net/links.html">on the OpenHBCI
website</a>.
</li>

<li>OpenHBCI <i>is not a server-side implementation</i> of %HBCI</li>

<li>OpenHBCI <i>is no eCash or online payment utility</i>. That is not
the scope of the %HBCI specification.</li> </ul>

@section authors Authors

Fabian Kaiser &lt;<a
href="mailto:fabian.kaiser@gmx.de">fabian.kaiser@gmx.de</a>&gt;,
Martin Preu&szlig; &lt;<a
href="mailto:martin@aquamaniac.de">martin@aquamaniac.de</a>&gt;,
Christian Stimming &lt;<a
href="mailto:stimming@tuhh.de">stimming@tuhh.de</a>&gt;
 */

/* end of documentation mainpage 
   //////////////////////////////////////////////////////////////////// */

#endif




