/* outboxjobkeys.h
    copyright   : (C) 2001 by Martin Preuss
    email       : openhbci@aquamaniac.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef OUTBOXJOBKEYS_H
#define OUTBOXJOBKEYS_H

/** @file outboxjobkeys.h
 *
 * @short Key management related Outboxjobs and their C wrappers. */

#ifdef __cplusplus
#include <string>
#include <list>
#endif /* __cplusplus */

#include <openhbci/dllimport.h>
#include <openhbci/pointer.h>
#include <openhbci/customer.h>
#include <openhbci/user.h>
#include <openhbci/bank.h>
#include <openhbci/account.h>
#include <openhbci/outboxjob.h>



#ifdef __cplusplus

namespace HBCI {

/**
 * @short Base class for key management
 * This job gets the servers keys or send ours. It is a base class for key
 * management.
 * @author Martin Preuss<martin@libchipcard.de>
 */
class DLLIMPORT OutboxJobKeys: public OutboxJob {
private:
    const API *_hbciapi;
    Pointer<Job> _initjob;
    Pointer<Job> _exitjob;
    bool _sendkeys;

protected:
    OutboxJobKeys(const API *api, Pointer<Customer> c, bool sk);
    ~OutboxJobKeys();

    bool createHBCIJobs(Pointer<MessageQueue> mbox, int n=0);
    bool evaluate();
    bool commit(int msgNumber=HBCI_COMMIT_WHOLE_JOB);
    string description() const { return "Key management";};
    bool isDialogJob() const { return true;};
    int messages() const { return 2;};
    list<int> resultCodes() const;
};

} /* namespace HBCI */
#endif /* __cplusplus */


#ifdef __cplusplus

namespace HBCI {
/**
 * This job gets the servers keys.
 * @short Job that gets the server keys
 * @author Martin Preuss<martin@libchipcard.de>
 */
class DLLIMPORT OutboxJobGetKeys: public OutboxJobKeys {
public:
    OutboxJobGetKeys(const API *api, Pointer<Customer> c);
    ~OutboxJobGetKeys();

    string description() const { return "Get Keys";};
    JobProgressType type() const { return JOB_GET_KEYS; };
};

} /* namespace HBCI */
/** @ingroup HBCI_OutboxJobg */
typedef struct HBCI::OutboxJobGetKeys HBCI_OutboxJobGetKeys;

extern "C" {
#else /* __cplusplus */
    typedef struct HBCI_OutboxJobGetKeys HBCI_OutboxJobGetKeys;
#endif /* __cplusplus */
    /** @name HBCI_OutboxJobGetKeys 
     * @ingroup HBCI_OutboxJobg */
    /*@{*/
    /** Constructor */
    extern HBCI_OutboxJobGetKeys *
    HBCI_OutboxJobGetKeys_new(const HBCI_API *api, const HBCI_Customer *c);
    /** Upcast */
    extern HBCI_OutboxJob *
    HBCI_OutboxJobGetKeys_OutboxJob(HBCI_OutboxJobGetKeys *j);
    /*@}*/
#ifdef __cplusplus
}

namespace HBCI {

/**
 * This job sends our keys.
 * @short Job that sends the keys of one Customer
 * (FIXME: this should rather be a User) to the server
 * @author Martin Preuss<martin@libchipcard.de>
 */
class DLLIMPORT OutboxJobSendKeys: public OutboxJobKeys {
public:
    OutboxJobSendKeys(const API *api, Pointer<Customer> c);
    ~OutboxJobSendKeys();

    string description() const { return "Send Keys";};
    JobProgressType type() const { return JOB_SEND_KEYS; };
};

} /* namespace HBCI */
/** @ingroup HBCI_OutboxJobg */
typedef struct HBCI::OutboxJobSendKeys HBCI_OutboxJobSendKeys;

extern "C" {
#else /* __cplusplus */
    typedef struct HBCI_OutboxJobSendKeys HBCI_OutboxJobSendKeys;
#endif /* __cplusplus */
    /** @name HBCI_OutboxJobSendKeys 
     * @ingroup HBCI_OutboxJobg */
    /*@{*/
    /** Constructor */
    extern HBCI_OutboxJobSendKeys *
    HBCI_OutboxJobSendKeys_new(const HBCI_API *api, const HBCI_Customer *c);
    /** Upcast */
    extern HBCI_OutboxJob *
    HBCI_OutboxJobSendKeys_OutboxJob(HBCI_OutboxJobSendKeys *j);
    /*@}*/
#ifdef __cplusplus
}
#endif /* __cplusplus */





#endif



